@@ -41,47 +41,68 @@ class Field(object):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'field_code': 'str',
         'link': 'WordsApiLink',
         'node_id': 'str',
-        'field_code': 'str',
         'locale_id': 'str',
         'result': 'str'
     }
 
     attribute_map = {
+        'field_code': 'FieldCode',
         'link': 'link',
         'node_id': 'NodeId',
-        'field_code': 'FieldCode',
         'locale_id': 'LocaleId',
         'result': 'Result'
     }
 
-    def __init__(self, link=None, node_id=None, field_code=None, locale_id=None, result=None):  # noqa: E501
+    def __init__(self, field_code=None, link=None, node_id=None, locale_id=None, result=None):  # noqa: E501
         """Field - a model defined in Swagger"""  # noqa: E501
 
+        self._field_code = None
         self._link = None
         self._node_id = None
-        self._field_code = None
         self._locale_id = None
         self._result = None
         self.discriminator = None
 
+        if field_code is not None:
+            self.field_code = field_code
         if link is not None:
             self.link = link
         if node_id is not None:
             self.node_id = node_id
-        if field_code is not None:
-            self.field_code = field_code
         if locale_id is not None:
             self.locale_id = locale_id
         if result is not None:
             self.result = result
 
     @property
+    def field_code(self):
+        """Gets the field_code of this Field.  # noqa: E501
+
+        Gets or sets field code.  # noqa: E501
+
+        :return: The field_code of this Field.  # noqa: E501
+        :rtype: str
+        """
+        return self._field_code
+
+    @field_code.setter
+    def field_code(self, field_code):
+        """Sets the field_code of this Field.
+
+        Gets or sets field code.  # noqa: E501
+
+        :param field_code: The field_code of this Field.  # noqa: E501
+        :type: str
+        """
+        self._field_code = field_code
+    @property
     def link(self):
         """Gets the link of this Field.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :return: The link of this Field.  # noqa: E501
         :rtype: WordsApiLink
@@ -92,7 +113,7 @@ class Field(object):
     def link(self, link):
         """Sets the link of this Field.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :param link: The link of this Field.  # noqa: E501
         :type: WordsApiLink
@@ -120,27 +141,6 @@ class Field(object):
         """
         self._node_id = node_id
     @property
-    def field_code(self):
-        """Gets the field_code of this Field.  # noqa: E501
-
-        Gets or sets field code.  # noqa: E501
-
-        :return: The field_code of this Field.  # noqa: E501
-        :rtype: str
-        """
-        return self._field_code
-
-    @field_code.setter
-    def field_code(self, field_code):
-        """Sets the field_code of this Field.
-
-        Gets or sets field code.  # noqa: E501
-
-        :param field_code: The field_code of this Field.  # noqa: E501
-        :type: str
-        """
-        self._field_code = field_code
-    @property
     def locale_id(self):
         """Gets the locale_id of this Field.  # noqa: E501
 
