@@ -41,8 +41,6 @@ class FormFieldDropDown(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'link': 'WordsApiLink',
-        'node_id': 'str',
         'calculate_on_exit': 'bool',
         'enabled': 'bool',
         'entry_macro': 'str',
@@ -52,13 +50,13 @@ class FormFieldDropDown(object):
         'own_help': 'bool',
         'own_status': 'bool',
         'status_text': 'str',
+        'link': 'WordsApiLink',
+        'node_id': 'str',
         'drop_down_items': 'list[str]',
         'drop_down_selected_index': 'int'
     }
 
     attribute_map = {
-        'link': 'link',
-        'node_id': 'NodeId',
         'calculate_on_exit': 'CalculateOnExit',
         'enabled': 'Enabled',
         'entry_macro': 'EntryMacro',
@@ -68,15 +66,15 @@ class FormFieldDropDown(object):
         'own_help': 'OwnHelp',
         'own_status': 'OwnStatus',
         'status_text': 'StatusText',
+        'link': 'link',
+        'node_id': 'NodeId',
         'drop_down_items': 'DropDownItems',
         'drop_down_selected_index': 'DropDownSelectedIndex'
     }
 
-    def __init__(self, link=None, node_id=None, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, drop_down_items=None, drop_down_selected_index=None):  # noqa: E501
+    def __init__(self, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, link=None, node_id=None, drop_down_items=None, drop_down_selected_index=None):  # noqa: E501
         """FormFieldDropDown - a model defined in Swagger"""  # noqa: E501
 
-        self._link = None
-        self._node_id = None
         self._calculate_on_exit = None
         self._enabled = None
         self._entry_macro = None
@@ -86,14 +84,12 @@ class FormFieldDropDown(object):
         self._own_help = None
         self._own_status = None
         self._status_text = None
+        self._link = None
+        self._node_id = None
         self._drop_down_items = None
         self._drop_down_selected_index = None
         self.discriminator = None
 
-        if link is not None:
-            self.link = link
-        if node_id is not None:
-            self.node_id = node_id
         if calculate_on_exit is not None:
             self.calculate_on_exit = calculate_on_exit
         if enabled is not None:
@@ -112,54 +108,16 @@ class FormFieldDropDown(object):
             self.own_status = own_status
         if status_text is not None:
             self.status_text = status_text
+        if link is not None:
+            self.link = link
+        if node_id is not None:
+            self.node_id = node_id
         if drop_down_items is not None:
             self.drop_down_items = drop_down_items
         if drop_down_selected_index is not None:
             self.drop_down_selected_index = drop_down_selected_index
 
     @property
-    def link(self):
-        """Gets the link of this FormFieldDropDown.  # noqa: E501
-
-        Gets or sets link to the document.  # noqa: E501
-
-        :return: The link of this FormFieldDropDown.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this FormFieldDropDown.
-
-        Gets or sets link to the document.  # noqa: E501
-
-        :param link: The link of this FormFieldDropDown.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
-    @property
-    def node_id(self):
-        """Gets the node_id of this FormFieldDropDown.  # noqa: E501
-
-        Gets or sets node id.  # noqa: E501
-
-        :return: The node_id of this FormFieldDropDown.  # noqa: E501
-        :rtype: str
-        """
-        return self._node_id
-
-    @node_id.setter
-    def node_id(self, node_id):
-        """Sets the node_id of this FormFieldDropDown.
-
-        Gets or sets node id.  # noqa: E501
-
-        :param node_id: The node_id of this FormFieldDropDown.  # noqa: E501
-        :type: str
-        """
-        self._node_id = node_id
-    @property
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldDropDown.  # noqa: E501
 
@@ -349,6 +307,48 @@ class FormFieldDropDown(object):
         """
         self._status_text = status_text
     @property
+    def link(self):
+        """Gets the link of this FormFieldDropDown.  # noqa: E501
+
+        Gets or sets link.  # noqa: E501
+
+        :return: The link of this FormFieldDropDown.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this FormFieldDropDown.
+
+        Gets or sets link.  # noqa: E501
+
+        :param link: The link of this FormFieldDropDown.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
+    @property
+    def node_id(self):
+        """Gets the node_id of this FormFieldDropDown.  # noqa: E501
+
+        Gets or sets node id.  # noqa: E501
+
+        :return: The node_id of this FormFieldDropDown.  # noqa: E501
+        :rtype: str
+        """
+        return self._node_id
+
+    @node_id.setter
+    def node_id(self, node_id):
+        """Sets the node_id of this FormFieldDropDown.
+
+        Gets or sets node id.  # noqa: E501
+
+        :param node_id: The node_id of this FormFieldDropDown.  # noqa: E501
+        :type: str
+        """
+        self._node_id = node_id
+    @property
     def drop_down_items(self):
         """Gets the drop_down_items of this FormFieldDropDown.  # noqa: E501
 
