@@ -71,7 +71,7 @@ class Hyperlink(object):
     def link(self):
         """Gets the link of this Hyperlink.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :return: The link of this Hyperlink.  # noqa: E501
         :rtype: WordsApiLink
@@ -82,7 +82,7 @@ class Hyperlink(object):
     def link(self, link):
         """Sets the link of this Hyperlink.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :param link: The link of this Hyperlink.  # noqa: E501
         :type: WordsApiLink
