@@ -237,7 +237,7 @@ class OoxmlSaveOptionsData(object):
     def update_sdt_content(self):
         """Gets the update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :return: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
         :rtype: bool
@@ -248,7 +248,7 @@ class OoxmlSaveOptionsData(object):
     def update_sdt_content(self, update_sdt_content):
         """Sets the update_sdt_content of this OoxmlSaveOptionsData.
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :param update_sdt_content: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
         :type: bool
