@@ -38,7 +38,7 @@ class InsertFieldRequest(object):
     :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
     :param revision_author Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.
     :param revision_date_time The date and time to use for revisions.
-    :param insert_before_node Field will be inserted before node with id=\"nodeId\".
+    :param insert_before_node Field will be inserted before node with id="nodeId".
     """
 
     def __init__(self, name, field, node_path, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None, insert_before_node=None):
