@@ -222,7 +222,7 @@ class SaveOptionsData(object):
     def update_sdt_content(self):
         """Gets the update_sdt_content of this SaveOptionsData.  # noqa: E501
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :return: The update_sdt_content of this SaveOptionsData.  # noqa: E501
         :rtype: bool
@@ -233,7 +233,7 @@ class SaveOptionsData(object):
     def update_sdt_content(self, update_sdt_content):
         """Sets the update_sdt_content of this SaveOptionsData.
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :param update_sdt_content: The update_sdt_content of this SaveOptionsData.  # noqa: E501
         :type: bool
