@@ -71,7 +71,7 @@ class SaveResult(object):
     def source_document(self):
         """Gets the source_document of this SaveResult.  # noqa: E501
 
-        Gets or sets link to source document.  # noqa: E501
+        Gets or sets source_document.  # noqa: E501
 
         :return: The source_document of this SaveResult.  # noqa: E501
         :rtype: FileLink
@@ -82,7 +82,7 @@ class SaveResult(object):
     def source_document(self, source_document):
         """Sets the source_document of this SaveResult.
 
-        Gets or sets link to source document.  # noqa: E501
+        Gets or sets source_document.  # noqa: E501
 
         :param source_document: The source_document of this SaveResult.  # noqa: E501
         :type: FileLink
@@ -92,7 +92,7 @@ class SaveResult(object):
     def dest_document(self):
         """Gets the dest_document of this SaveResult.  # noqa: E501
 
-        Gets or sets link to destination document.  # noqa: E501
+        Gets or sets dest_document.  # noqa: E501
 
         :return: The dest_document of this SaveResult.  # noqa: E501
         :rtype: FileLink
@@ -103,7 +103,7 @@ class SaveResult(object):
     def dest_document(self, dest_document):
         """Sets the dest_document of this SaveResult.
 
-        Gets or sets link to destination document.  # noqa: E501
+        Gets or sets dest_document.  # noqa: E501
 
         :param dest_document: The dest_document of this SaveResult.  # noqa: E501
         :type: FileLink
