@@ -87,7 +87,7 @@ class SectionPageSetupResponse(object):
     def page_setup(self):
         """Gets the page_setup of this SectionPageSetupResponse.  # noqa: E501
 
-        Gets or sets section.  # noqa: E501
+        Gets or sets page_setup.  # noqa: E501
 
         :return: The page_setup of this SectionPageSetupResponse.  # noqa: E501
         :rtype: PageSetup
@@ -98,7 +98,7 @@ class SectionPageSetupResponse(object):
     def page_setup(self, page_setup):
         """Sets the page_setup of this SectionPageSetupResponse.
 
-        Gets or sets section.  # noqa: E501
+        Gets or sets page_setup.  # noqa: E501
 
         :param page_setup: The page_setup of this SectionPageSetupResponse.  # noqa: E501
         :type: PageSetup
