@@ -71,7 +71,7 @@ class SplitDocumentResult(object):
     def source_document(self):
         """Gets the source_document of this SplitDocumentResult.  # noqa: E501
 
-        Gets or sets linkt to the source document.  # noqa: E501
+        Gets or sets source_document.  # noqa: E501
 
         :return: The source_document of this SplitDocumentResult.  # noqa: E501
         :rtype: FileLink
@@ -82,7 +82,7 @@ class SplitDocumentResult(object):
     def source_document(self, source_document):
         """Sets the source_document of this SplitDocumentResult.
 
-        Gets or sets linkt to the source document.  # noqa: E501
+        Gets or sets source_document.  # noqa: E501
 
         :param source_document: The source_document of this SplitDocumentResult.  # noqa: E501
         :type: FileLink
@@ -113,7 +113,7 @@ class SplitDocumentResult(object):
     def zipped_pages(self):
         """Gets the zipped_pages of this SplitDocumentResult.  # noqa: E501
 
-        Gets or sets link to the file archive with pages.  # noqa: E501
+        Gets or sets zipped_pages.  # noqa: E501
 
         :return: The zipped_pages of this SplitDocumentResult.  # noqa: E501
         :rtype: FileLink
@@ -124,7 +124,7 @@ class SplitDocumentResult(object):
     def zipped_pages(self, zipped_pages):
         """Sets the zipped_pages of this SplitDocumentResult.
 
-        Gets or sets link to the file archive with pages.  # noqa: E501
+        Gets or sets zipped_pages.  # noqa: E501
 
         :param zipped_pages: The zipped_pages of this SplitDocumentResult.  # noqa: E501
         :type: FileLink
