@@ -87,7 +87,7 @@ class TableRowResponse(object):
     def row(self):
         """Gets the row of this TableRowResponse.  # noqa: E501
 
-        Gets or sets table row.  # noqa: E501
+        Gets or sets row.  # noqa: E501
 
         :return: The row of this TableRowResponse.  # noqa: E501
         :rtype: TableRow
@@ -98,7 +98,7 @@ class TableRowResponse(object):
     def row(self, row):
         """Sets the row of this TableRowResponse.
 
-        Gets or sets table row.  # noqa: E501
+        Gets or sets row.  # noqa: E501
 
         :param row: The row of this TableRowResponse.  # noqa: E501
         :type: TableRow
