@@ -227,7 +227,7 @@ class WordMLSaveOptionsData(object):
     def update_sdt_content(self):
         """Gets the update_sdt_content of this WordMLSaveOptionsData.  # noqa: E501
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :return: The update_sdt_content of this WordMLSaveOptionsData.  # noqa: E501
         :rtype: bool
@@ -238,7 +238,7 @@ class WordMLSaveOptionsData(object):
     def update_sdt_content(self, update_sdt_content):
         """Sets the update_sdt_content of this WordMLSaveOptionsData.
 
-        Gets or sets value determining whether content of  is updated before saving.  # noqa: E501
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
 
         :param update_sdt_content: The update_sdt_content of this WordMLSaveOptionsData.  # noqa: E501
         :type: bool
